PyXMake Developer Guide: PyXMake.Tools.Utility.AbstractBase Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | List of all members
PyXMake.Tools.Utility.AbstractBase Class Reference

Abstract meta class for all data class objects. More...

Inheritance diagram for PyXMake.Tools.Utility.AbstractBase:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Static Public Member Functions
| __getbase__ (base, cls)

## Detailed Description

Abstract meta class for all data class objects.

    Parent class for all abstract base classes.

Inherited from built-in ABCMeta & object. Compatible with both Python 2.x and 3.x.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.AbstractBase.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Low-level initialization of parent class.

Reimplemented in PyXMake.API.Backend, PyXMake.API.Frontend, PyXMake.Build.Make.CCxx, PyXMake.Build.Make.Coverage, PyXMake.Build.Make.Custom, PyXMake.Build.Make.Doxygen, PyXMake.Build.Make.Fortran, PyXMake.Build.Make.Latex, PyXMake.Build.Make.Make, PyXMake.Build.Make.NSIS, PyXMake.Build.Make.NT, PyXMake.Build.Make.OS, PyXMake.Build.Make.POSIX, PyXMake.Build.Make.Py2X, PyXMake.Build.Make.PyInstaller, PyXMake.Build.Make.PyReq, PyXMake.Build.Make.Sphinx, PyXMake.Build.Make.SSH, PyXMake.Tools.ErrorHandling.InputError, and PyXMake.Tools.ErrorHandling.TransitionError.

Definition at line 166 of file Utility.py.

## Member Function Documentation

## ◆ __getbase__()

PyXMake.Tools.Utility.AbstractBase.__getbase__ | ( |  | base,
|  |  | cls )
| static

    Recursively find the common ancestor in all bases for a given class and compare them with the supplied base.

    @note: Returns None if no common ancestor can be found

Definition at line 256 of file Utility.py.

## ◆ __getstate__()

PyXMake.Tools.Utility.AbstractBase.__getstate__ | ( |  | self | ) |

    Prepare the object for pickling (2to3 compatible)

Definition at line 240 of file Utility.py.

## ◆ __new__()

PyXMake.Tools.Utility.AbstractBase.__new__ | ( |  | cls,
|  | * | args,
|  | ** | kwargs )

    Check if the current base is an abstract base.

Definition at line 173 of file Utility.py.

## ◆ __repr__()

PyXMake.Tools.Utility.AbstractBase.__repr__ | ( |  | self | ) |

    Returns a string representation of the current instance.

Definition at line 228 of file Utility.py.

## ◆ __setstate__()

PyXMake.Tools.Utility.AbstractBase.__setstate__ | ( |  | self,
|  |  | _dict )

    Recover a dictionary from pickling (2to3 compatible)

Definition at line 247 of file Utility.py.

## ◆ __str__()

PyXMake.Tools.Utility.AbstractBase.__str__ | ( |  | self | ) |

    Prepare an object for JSON (2to3 compatible). Returns a canonical data representation of the current instance.

Definition at line 234 of file Utility.py.

## ◆ classify()

PyXMake.Tools.Utility.AbstractBase.classify | ( |  | cls,
|  | * | args,
|  | ** | kwargs )

    Serializes an arbitrary data class instantiation call. Returns the complete class as JSON.

Definition at line 205 of file Utility.py.

## ◆ jsonify()

PyXMake.Tools.Utility.AbstractBase.jsonify | ( |  | self | ) |

    Create a JSON representation of the current class

Definition at line 215 of file Utility.py.

## ◆ recover()

PyXMake.Tools.Utility.AbstractBase.recover | ( |  | cls,
|  | * | args )

    Recover a derived data class completely from its JSON or dictionary form.

Definition at line 184 of file Utility.py.

## ◆ update()

PyXMake.Tools.Utility.AbstractBase.update | ( |  | self,
|  | ** | kwargs )

    Update any given class attribute.

Definition at line 221 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py